from .registry import register_variables_extractor, register_assertion


def variable_extractor(key):
    def decorator(function):
        register_variables_extractor(key, function)
        return function
    return decorator


def assertion(key):
    def decorator(function):
        register_assertion(key, function)
        return function
    return decorator



EXTRACTORS = {}
ASSERTIONS = {}


def register_variables_extractor(name, extractor):
    EXTRACTORS[name] = extractor


def unregister_variables_extractor(name):
    del EXTRACTORS[name]


def get_variables_extractors():
    return EXTRACTORS


def get_variables_extractor(name):
    try:
        return EXTRACTORS[name]
    except KeyError:
        raise UnregisteredVariablesExtractor(name)


class UnregisteredVariablesExtractor(Exception):
    pass


def register_assertion(name, assertion):
    ASSERTIONS[name] = assertion


def unregister_assertion(name):
    del ASSERTIONS[name]


def get_assertions():
    return ASSERTIONS


def get_assertion(name):
    try:
        return ASSERTIONS[name]
    except KeyError:
        raise UnregisteredAssertion(name)


class UnregisteredAssertion(Exception):
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = 'Marek Wywiał'
__email__ = 'onjinx@gmail.com'
__version__ = '0.3.2'

from .variable_extractor import json_variables_extractor
from .assertions import (
    in_assertion, notin_assertion, empty_assertion, notempty_assertion,
    equals_assertion, notequals_assertion
)

__all__ = [
    json_variables_extractor, in_assertion, notin_assertion, empty_assertion,
    notempty_assertion, equals_assertion, notequals_assertion
]



from .decorators import assertion


@assertion('equals')
def equals_assertion(value, params):
    return str(value) == str(params)


@assertion('notequals')
def notequals_assertion(value, params):
    return not equals_assertion(value, params)


@assertion('in')
def in_assertion(value, params):
    return str(value) in params.split(',')


@assertion('notin')
def notin_assertion(value, params):
    return not in_assertion(value, params)


@assertion('empty')
def empty_assertion(value):
    if value is None:
        return True
    return not str(value)


@assertion('notempty')
def notempty_assertion(value):
    return not empty_assertion(value)


@assertion('contains')
def contains_assertion(value, params):
    return str(params) in str(value)


@assertion('notcontains')
def notcontains_assertion(value, params):
    return not contains_assertion(value, params)
